from wagtail.contrib.modeladmin.options import ModelAdmin
from wagtail_rest_pack.comments.models import Comment

class CommentsModelAdmin(ModelAdmin):
    model = Comment
    menu_label = 'Comments'
    menu_icon = 'form'
    menu_order = 200
    add_to_settings_menu = False  # or True to add your model to the Settings sub-menu
    exclude_from_explorer = False  # or True to exclude pages of this type from Wagtail's explorer view
    list_display = ('body', 'created_on', 'created_by', 'parent',)
    list_filter = ('created_on',)
    search_fields = ('body', 'created_by',)



# Generated by Django 3.2.3 on 2021-05-26 18:16

from django.db import migrations
import django.db.models.deletion
import modelcluster.fields


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0062_comment_models_and_pagesubscription'),
        ('custom_tag', '0004_pagetag'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pagetag',
            name='content_object',
            field=modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='custom_tag_pagetag_items', to='wagtailcore.page'),
        ),
    ]



# Generated by Django 3.2 on 2021-05-04 15:47

from django.db import migrations
import wagtail.blocks
import wagtail.fields
import wagtail_rest_pack.generic_forms.blocks.generic_input


class Migration(migrations.Migration):

    dependencies = [
        ('generic_forms', '0008_alter_formbuilder_stream'),
    ]

    operations = [
        migrations.AlterField(
            model_name='formbuilder',
            name='stream',
            field=wagtail.fields.StreamField([('form_text', wagtail.blocks.StructBlock([('name', wagtail.blocks.TextBlock(help_text='Název pole v ascii (např. user_email)', label='Technický název pole', max_length=30, validators=[wagtail_rest_pack.generic_forms.blocks.generic_input.is_form_field])), ('label', wagtail.blocks.TextBlock(label='Popisek zobrazený před inputem.', max_length=50)), ('max_length', wagtail.blocks.IntegerBlock(default=100, help_text='Maximální délka vstupu', label='Max', max_value=2000, min_value=10)), ('required', wagtail.blocks.ChoiceBlock(choices=[('always', 'Vždy'), ('anonymous_user_only', 'Pouze nepřihlášený uživatel')], label='Podmínka zobrazení pole')), ('placeholder', wagtail.blocks.CharBlock(help_text='Hodnota zobrazená, když nic není vyplněno.', max_length=80, required=False)), ('validation', wagtail.blocks.ChoiceBlock(choices=[('none', 'Žádné'), ('email', 'Email')], label='Validace')), ('multiline', wagtail.blocks.BooleanBlock(help_text='Víceřádkový vstup.', required=False))])), ('form_group', wagtail.blocks.StructBlock([('name', wagtail.blocks.CharBlock(max_length=80)), ('row', wagtail.blocks.BooleanBlock(default=False, label='Zobrazit na jednom řádku.', required=False)), ('required', wagtail.blocks.ChoiceBlock(choices=[('always', 'Vždy'), ('anonymous_user_only', 'Pouze nepřihlášený uživatel')], label='Podmínka zobrazení pole')), ('stream', wagtail.blocks.StreamBlock([('form_text', wagtail.blocks.StructBlock([('name', wagtail.blocks.TextBlock(help_text='Název pole v ascii (např. user_email)', label='Technický název pole', max_length=30, validators=[wagtail_rest_pack.generic_forms.blocks.generic_input.is_form_field])), ('label', wagtail.blocks.TextBlock(label='Popisek zobrazený před inputem.', max_length=50)), ('max_length', wagtail.blocks.IntegerBlock(default=100, help_text='Maximální délka vstupu', label='Max', max_value=2000, min_value=10)), ('required', wagtail.blocks.ChoiceBlock(choices=[('always', 'Vždy'), ('anonymous_user_only', 'Pouze nepřihlášený uživatel')], label='Podmínka zobrazení pole')), ('placeholder', wagtail.blocks.CharBlock(help_text='Hodnota zobrazená, když nic není vyplněno.', max_length=80, required=False)), ('validation', wagtail.blocks.ChoiceBlock(choices=[('none', 'Žádné'), ('email', 'Email')], label='Validace')), ('multiline', wagtail.blocks.BooleanBlock(help_text='Víceřádkový vstup.', required=False))]))]))])), ('form_submit', wagtail.blocks.StructBlock([('name', wagtail.blocks.TextBlock(help_text='Název pole v ascii (např. user_email)', label='Jméno', max_length=30, validators=[])), ('text', wagtail.blocks.CharBlock(label='Text na tlačítku', max_length=30)), ('action', wagtail.blocks.StreamBlock([('send_email', wagtail.blocks.StructBlock([('sender', wagtail.blocks.CharBlock(label='Nazev technického pole, ve kterém bude vyplněn odesílatel.', max_length=50)), ('address', wagtail.blocks.EmailBlock(label='Adresát.', max_length=150))]))], label='Akce', max_num=1, min_num=1)), ('response', wagtail.blocks.StreamBlock([('form_open_dialog', wagtail.blocks.StructBlock([('title', wagtail.blocks.TextBlock(help_text='Titulek', max_length=40, required=True)), ('text', wagtail.blocks.StreamBlock([('richtext', wagtail.blocks.RichTextBlock(icon='doc-full'))]))])), ('form_open_snack', wagtail.blocks.StructBlock([('text', wagtail.blocks.TextBlock(max_length=50, required=True))]))], label='Odpověď', max_num=1, min_num=1))]))]),
        ),
    ]



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _

class StreamfieldConfig(AppConfig):
    name = 'wagtail_rest_pack.streamfield'
    verbose_name = _('StreamField Additions')

    def ready(self):
        pass
        # super().ready()


from django.conf import settings
from django.http import HttpResponse

class VersionMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response
        self.version = getattr(settings, 'APPLICATION_VERSION', None)
        assert self.version is not None, (
            'The `APPLICATION_VERSION` must be set in order to use VersionMiddleware.'
        )

    def __call__(self, request):
        accept_version = request.headers.get('if-version')
        if accept_version is not None:
            if accept_version != self.version:
                response = self.get_response(request)
                return HttpResponse(status=412)
        response = self.get_response(request)
        response["Version"] = self.version
        return response



# Generated by Django 3.2.3 on 2021-05-26 16:04

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0062_comment_models_and_pagesubscription'),
    ]

    operations = [
        migrations.CreateModel(
            name='Relation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('from_page', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='from_page', to='wagtailcore.page')),
                ('to_page', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='to_page', to='wagtailcore.page')),
            ],
            options={
                'unique_together': {('from_page', 'to_page')},
            },
        ),
    ]



from .response import FormResponse
from wagtail import blocks


class ShowSnackResponse(FormResponse):
    type='form_open_snack'

    @staticmethod
    def block_definition() ->tuple:
        return ShowSnackResponse.type, blocks.StructBlock(local_blocks=[
            ('text', blocks.TextBlock(required=True, max_length=50))
        ])



# Generated by Django 3.2.3 on 2021-05-26 18:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailcore', '0062_comment_models_and_pagesubscription'),
        ('taggit', '0003_taggeditem_add_unique_index'),
        ('custom_tag', '0003_tag'),
    ]

    operations = [
        migrations.CreateModel(
            name='PageTag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content_object', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='custom_tag_pagetag_items', to='wagtailcore.page')),
                ('tag', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='custom_tag_pagetag_items', to='taggit.tag')),
            ],
            options={
                'abstract': False,
            },
        ),
    ]



# Generated by Django 3.1.8 on 2021-05-11 16:31

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('custom_tag', '0001_initial'),
    ]

    operations = [
        migrations.DeleteModel(
            name='PageTag',
        ),
    ]



# Generated by Django 3.1.8 on 2021-05-10 14:31

from django.db import migrations
import wagtail.fields


class Migration(migrations.Migration):

    dependencies = [
        ('sitesettings', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='imageslideritem',
            name='text',
            field=wagtail.fields.RichTextField(default='', help_text='Text', max_length=200),
        ),
    ]



from django.db import models
from modelcluster.fields import ParentalKey
from taggit.models import TaggedItemBase
from wagtail.models import Page
from wagtail.snippets.models import register_snippet
from taggit.models import Tag as TaggitTag
from django.utils.translation import gettext_lazy as _


@register_snippet
class Tag(TaggitTag):
    class Meta:
        verbose_name = _('Štítek')
        verbose_name_plural = _('Štítky')
        proxy = True


class PageTag(TaggedItemBase):
    content_object = ParentalKey(
        Page,
        related_name='%(app_label)s_%(class)s_items',
        on_delete=models.CASCADE,
    )



from django.http import Http404
from rest_framework.response import Response
from wagtail.api.v2.views import PagesAPIViewSet
from wagtail.api.v2.router import WagtailAPIRouter
from wagtail.api.v2.serializers import PageSerializer
from wagtail.models import Page
from rest_framework.permissions import AllowAny

class NotRedirectWhenFindViewPagesApiViewSet(PagesAPIViewSet):

    def find_view(self, request):
        queryset = self.get_queryset()
        try:
            obj = self.find_object(queryset, request)
            if obj is None:
                raise self.model.DoesNotExist
        except self.model.DoesNotExist:
            raise Http404("not found")
        self.kwargs['pk'] = obj.pk
        serializer = self.get_serializer(obj)
        return Response(serializer.data)



# Generated by Django 3.1.8 on 2021-05-12 13:54

from django.db import migrations
import wagtail.blocks
import wagtail.fields
import wagtail_rest_pack.streamfield.image


class Migration(migrations.Migration):

    dependencies = [
        ('streamfield', '0004_gallery'),
    ]

    operations = [
        migrations.AlterField(
            model_name='gallery',
            name='stream',
            field=wagtail.fields.StreamField([('gallery_image', wagtail.blocks.StructBlock([('image', wagtail.images.blocks.ImageChooserBlock())], icon='image', label='Image'))]),
        ),
    ]



# Generated by Django 3.2.16 on 2022-10-23 08:45

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('custom_tag', '0005_alter_pagetag_content_object'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='tag',
            options={'verbose_name': 'Štítek', 'verbose_name_plural': 'Štítky'},
        ),
    ]



# Generated by Django 3.1.8 on 2021-05-11 16:13

from django.db import migrations, models
import django.db.models.deletion
import modelcluster.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('wagtailcore', '0060_fix_workflow_unique_constraint'),
        ('taggit', '0003_taggeditem_add_unique_index'),
    ]

    operations = [
        migrations.CreateModel(
            name='PageTag',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content_object', modelcluster.fields.ParentalKey(on_delete=django.db.models.deletion.CASCADE, related_name='tagged_pages', to='wagtailcore.page')),
                ('tag', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='wagtail_rest_pack_pagetag_items', to='taggit.tag')),
            ],
        ),
    ]



from rest_framework import serializers
from wagtail.documents import get_document_model

class DocumentSerializer(serializers.ModelSerializer):
    document = serializers.SerializerMethodField('create_doc')

    class Meta:
        model = get_document_model()
        fields = ['document',]

    def create_doc(self, data):
        return {
            'id': data.id,
            'title': data.title,
            'contentType': data.content_type,
            'size': data.file.size,
            'url' : data.file.url,
            'ext': data.file_extension,
            'filename': data.filename
        }



from django.template.loader import render_to_string

from wagtail.embeds import embeds
from wagtail.embeds.exceptions import EmbedException
from wagtail.rich_text import EmbedHandler
from wagtail.embeds import format
from wagtail.embeds.embeds import get_embed
from wagtail.embeds.models import Embed


#  here here
def embed_to_frontend_html(attrs):
    try:
        url = attrs['url']
        type = attrs['embedtype']
        embed = embeds.get_embed(url)
        embed.html = embed.html.replace("feature=oembed", "feature=oembed&autoplay=1")
        add = 'data-thumbnail="%s"' % embed.thumbnail_url
        add += ' data-title="%s"' % embed.title
        add += ' data-type="'+type+'"'
        embed.html = embed.html.replace(" src=", " %s src=" % add)
        # Render template
        return render_to_string('wagtailembeds/embed_frontend.html', {
            'embed': embed,
        })
    except EmbedException:
        # silently ignore failed embeds, rather than letting them crash the page
        return ''

class ThumbnailedEmbedHandler(EmbedHandler):
    identifier = 'media'

    @staticmethod
    def get_model():
        return Embed

    @staticmethod
    def get_instance(attrs):
        return get_embed(attrs['url'])

    @staticmethod
    def expand_db_attributes(attrs):
        return embed_to_frontend_html(attrs)
